@@ -1,4 +1,4 @@
-// Copyright (c) 2017-2022 Advanced Micro Devices, Inc. All rights reserved.
+// Copyright (c) 2017-2025 Advanced Micro Devices, Inc. All rights reserved.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -26,11 +26,6 @@
 #ifndef ROCRAND_UNIFORM_H_
 #define ROCRAND_UNIFORM_H_
 
-/// Shorthand for commonly used function qualifiers
-#ifndef FQUALIFIERS
-#define FQUALIFIERS __forceinline__ __device__
-#endif // FQUALIFIERS
-
 #include "rocrand/rocrand_lfsr113.h"
 #include "rocrand/rocrand_mrg31k3p.h"
 #include "rocrand/rocrand_mrg32k3a.h"
@@ -48,6 +43,8 @@
 
 #include "rocrand/rocrand_common.h"
 
+#include <hip/hip_runtime.h>
+
 namespace rocrand_device {
 namespace detail {
 
@@ -65,22 +62,19 @@ union two_uints_to_ulong
 
 // For unsigned integer between 0 and UINT_MAX, returns value between
 // 0.0f and 1.0f, excluding 0.0f and including 1.0f.
-FQUALIFIERS
-float uniform_distribution(unsigned int v)
+__forceinline__ __device__ __host__ float uniform_distribution(unsigned int v)
 {
     return ROCRAND_2POW32_INV + (v * ROCRAND_2POW32_INV);
 }
 
 // For unsigned integer between 0 and ULLONG_MAX, returns value between
 // 0.0f and 1.0f, excluding 0.0f and including 1.0f.
-FQUALIFIERS
-float uniform_distribution(unsigned long long int v)
+__forceinline__ __device__ __host__ float uniform_distribution(unsigned long long int v)
 {
     return ROCRAND_2POW32_INV + (v >> 32) * ROCRAND_2POW32_INV;
 }
 
-FQUALIFIERS
-float4 uniform_distribution4(uint4 v)
+__forceinline__ __device__ __host__ float4 uniform_distribution4(uint4 v)
 {
    return float4 {
        ROCRAND_2POW32_INV + (v.x * ROCRAND_2POW32_INV),
@@ -90,7 +84,7 @@ float4 uniform_distribution4(uint4 v)
    };
 }
 
-FQUALIFIERS float4 uniform_distribution4(ulonglong4 v)
+__forceinline__ __device__ __host__ float4 uniform_distribution4(ulonglong4 v)
 {
     return float4{ROCRAND_2POW64_INV + (v.x * ROCRAND_2POW64_INV),
                   ROCRAND_2POW64_INV + (v.y * ROCRAND_2POW64_INV),
@@ -100,14 +94,13 @@ FQUALIFIERS float4 uniform_distribution4(ulonglong4 v)
 
 // For unsigned integer between 0 and UINT_MAX, returns value between
 // 0.0 and 1.0, excluding 0.0 and including 1.0.
-FQUALIFIERS
-double uniform_distribution_double(unsigned int v)
+__forceinline__ __device__ __host__ double uniform_distribution_double(unsigned int v)
 {
     return ROCRAND_2POW32_INV_DOUBLE + (v * ROCRAND_2POW32_INV_DOUBLE);
 }
 
-FQUALIFIERS
-double uniform_distribution_double(unsigned int v1, unsigned int v2)
+__forceinline__ __device__ __host__ double uniform_distribution_double(unsigned int v1,
+                                                                       unsigned int v2)
 {
     two_uints_to_ulong v;
     v.uint2_value.x = v1;
@@ -115,8 +108,7 @@ double uniform_distribution_double(unsigned int v1, unsigned int v2)
     return ROCRAND_2POW53_INV_DOUBLE + (v.ulong_value * ROCRAND_2POW53_INV_DOUBLE);
 }
 
-FQUALIFIERS
-double uniform_distribution_double(unsigned long long int v)
+__forceinline__ __device__ __host__ double uniform_distribution_double(unsigned long long int v)
 {
     return ROCRAND_2POW53_INV_DOUBLE + (
         // 2^53 is the biggest int that can be stored in double, such
@@ -125,8 +117,7 @@ double uniform_distribution_double(unsigned long long int v)
     );
 }
 
-FQUALIFIERS
-double2 uniform_distribution_double2(uint4 v)
+__forceinline__ __device__ __host__ double2 uniform_distribution_double2(uint4 v)
 {
     return double2 {
         uniform_distribution_double(v.x, v.y),
@@ -134,8 +125,7 @@ double2 uniform_distribution_double2(uint4 v)
     };
 }
 
-FQUALIFIERS
-double4 uniform_distribution_double4(uint4 v1, uint4 v2)
+__forceinline__ __device__ __host__ double4 uniform_distribution_double4(uint4 v1, uint4 v2)
 {
     return double4 {
         uniform_distribution_double(v1.x, v1.y),
@@ -145,17 +135,17 @@ double4 uniform_distribution_double4(uint4 v1, uint4 v2)
     };
 }
 
-FQUALIFIERS double2 uniform_distribution_double2(ulonglong2 v)
+__forceinline__ __device__ __host__ double2 uniform_distribution_double2(ulonglong2 v)
 {
     return double2{uniform_distribution_double(v.x), uniform_distribution_double(v.y)};
 }
 
-FQUALIFIERS double2 uniform_distribution_double2(ulonglong4 v)
+__forceinline__ __device__ __host__ double2 uniform_distribution_double2(ulonglong4 v)
 {
     return double2{uniform_distribution_double(v.x), uniform_distribution_double(v.y)};
 }
 
-FQUALIFIERS double4 uniform_distribution_double4(ulonglong4 v)
+__forceinline__ __device__ __host__ double4 uniform_distribution_double4(ulonglong4 v)
 {
     return double4{uniform_distribution_double(v.x),
                    uniform_distribution_double(v.z),
@@ -163,8 +153,7 @@ FQUALIFIERS double4 uniform_distribution_double4(ulonglong4 v)
                    uniform_distribution_double(v.z)};
 }
 
-FQUALIFIERS
-__half uniform_distribution_half(unsigned short v)
+__forceinline__ __device__ __host__ __half uniform_distribution_half(unsigned short v)
 {
     return __float2half(ROCRAND_2POW16_INV + (v * ROCRAND_2POW16_INV));
 }
@@ -172,16 +161,19 @@ __half uniform_distribution_half(unsigned short v)
 // For an unsigned integer produced by an MRG-based engine, returns a value
 // in range [0, UINT32_MAX].
 template<typename state_type>
-FQUALIFIERS unsigned int mrg_uniform_distribution_uint(unsigned int v) = delete;
+__forceinline__ __device__ __host__ unsigned int mrg_uniform_distribution_uint(unsigned int v)
+    = delete;
 
 template<>
-FQUALIFIERS unsigned int mrg_uniform_distribution_uint<rocrand_state_mrg31k3p>(unsigned int v)
+__forceinline__ __device__ __host__ unsigned int
+    mrg_uniform_distribution_uint<rocrand_state_mrg31k3p>(unsigned int v)
 {
     return static_cast<unsigned int>((v - 1) * ROCRAND_MRG31K3P_UINT32_NORM);
 }
 
 template<>
-FQUALIFIERS unsigned int mrg_uniform_distribution_uint<rocrand_state_mrg32k3a>(unsigned int v)
+__forceinline__ __device__ __host__ unsigned int
+    mrg_uniform_distribution_uint<rocrand_state_mrg32k3a>(unsigned int v)
 {
     return static_cast<unsigned int>((v - 1) * ROCRAND_MRG32K3A_UINT_NORM);
 }
@@ -189,17 +181,19 @@ FQUALIFIERS unsigned int mrg_uniform_distribution_uint<rocrand_state_mrg32k3a>(u
 // For an unsigned integer produced by an MRG-based engine, returns value between
 // 0.0f and 1.0f, excluding 0.0f and including 1.0f.
 template<typename state_type>
-FQUALIFIERS float mrg_uniform_distribution(unsigned int v) = delete;
+__forceinline__ __device__ __host__ float mrg_uniform_distribution(unsigned int v) = delete;
 
 template<>
-FQUALIFIERS float mrg_uniform_distribution<rocrand_state_mrg31k3p>(unsigned int v)
+__forceinline__ __device__ __host__ float
+    mrg_uniform_distribution<rocrand_state_mrg31k3p>(unsigned int v)
 {
     double ret = static_cast<double>(v) * ROCRAND_MRG31K3P_NORM_DOUBLE;
     return static_cast<float>(ret);
 }
 
 template<>
-FQUALIFIERS float mrg_uniform_distribution<rocrand_state_mrg32k3a>(unsigned int v)
+__forceinline__ __device__ __host__ float
+    mrg_uniform_distribution<rocrand_state_mrg32k3a>(unsigned int v)
 {
     double ret = static_cast<double>(v) * ROCRAND_MRG32K3A_NORM_DOUBLE;
     return static_cast<float>(ret);
@@ -208,17 +202,19 @@ FQUALIFIERS float mrg_uniform_distribution<rocrand_state_mrg32k3a>(unsigned int
 // For an unsigned integer produced by an MRG generator, returns value between
 // 0.0 and 1.0, excluding 0.0 and including 1.0.
 template<typename state_type>
-FQUALIFIERS double mrg_uniform_distribution_double(unsigned int v) = delete;
+__forceinline__ __device__ __host__ double mrg_uniform_distribution_double(unsigned int v) = delete;
 
 template<>
-FQUALIFIERS double mrg_uniform_distribution_double<rocrand_state_mrg31k3p>(unsigned int v)
+__forceinline__ __device__ __host__ double
+    mrg_uniform_distribution_double<rocrand_state_mrg31k3p>(unsigned int v)
 {
     double ret = static_cast<double>(v) * ROCRAND_MRG31K3P_NORM_DOUBLE;
     return ret;
 }
 
 template<>
-FQUALIFIERS double mrg_uniform_distribution_double<rocrand_state_mrg32k3a>(unsigned int v)
+__forceinline__ __device__ __host__ double
+    mrg_uniform_distribution_double<rocrand_state_mrg32k3a>(unsigned int v)
 {
     double ret = static_cast<double>(v) * ROCRAND_MRG32K3A_NORM_DOUBLE;
     return ret;
@@ -235,12 +231,12 @@ FQUALIFIERS double mrg_uniform_distribution_double<rocrand_state_mrg32k3a>(unsig
  * (excluding \p 0.0f, including \p 1.0f) using Philox generator in \p state, and
  * increments position of the generator by one.
  *
- * \param state - Pointer to a state to use
+ * \param state Pointer to a state to use
  *
  * \return Uniformly distributed \p float value from (0; 1] range.
  */
-FQUALIFIERS
-float rocrand_uniform(rocrand_state_philox4x32_10 * state)
+__forceinline__ __device__ __host__
+float rocrand_uniform(rocrand_state_philox4x32_10* state)
 {
     return rocrand_device::detail::uniform_distribution(rocrand(state));
 }
@@ -253,12 +249,12 @@ float rocrand_uniform(rocrand_state_philox4x32_10 * state)
  * (excluding \p 0.0f, including \p 1.0f) using Philox generator in \p state, and
  * increments position of the generator by two.
  *
- * \param state - Pointer to a state to use
+ * \param state Pointer to a state to use
  *
  * \return Two uniformly distributed \p float values from (0; 1] range as \p float2.
  */
-FQUALIFIERS
-float2 rocrand_uniform2(rocrand_state_philox4x32_10 * state)
+__forceinline__ __device__ __host__
+float2 rocrand_uniform2(rocrand_state_philox4x32_10* state)
 {
     auto state1 = rocrand(state);
     auto state2 = rocrand(state);
@@ -277,12 +273,12 @@ float2 rocrand_uniform2(rocrand_state_philox4x32_10 * state)
  * (excluding \p 0.0f, including \p 1.0f) using Philox generator in \p state, and
  * increments position of the generator by four.
  *
- * \param state - Pointer to a state to use
+ * \param state Pointer to a state to use
  *
  * \return Four uniformly distributed \p float values from (0; 1] range as \p float4.
  */
-FQUALIFIERS
-float4 rocrand_uniform4(rocrand_state_philox4x32_10 * state)
+__forceinline__ __device__ __host__
+float4 rocrand_uniform4(rocrand_state_philox4x32_10* state)
 {
     return rocrand_device::detail::uniform_distribution4(rocrand4(state));
 }
@@ -295,12 +291,12 @@ float4 rocrand_uniform4(rocrand_state_philox4x32_10 * state)
  * (excluding \p 0.0, including \p 1.0) using Philox generator in \p state, and
  * increments position of the generator by two.
  *
- * \param state - Pointer to a state to use
+ * \param state Pointer to a state to use
  *
  * \return Uniformly distributed \p double value from (0; 1] range.
  */
-FQUALIFIERS
-double rocrand_uniform_double(rocrand_state_philox4x32_10 * state)
+__forceinline__ __device__ __host__
+double rocrand_uniform_double(rocrand_state_philox4x32_10* state)
 {
     auto state1 = rocrand(state);
     auto state2 = rocrand(state);
@@ -316,12 +312,12 @@ double rocrand_uniform_double(rocrand_state_philox4x32_10 * state)
  * (excluding \p 0.0, including \p 1.0) using Philox generator in \p state, and
  * increments position of the generator by four.
  *
- * \param state - Pointer to a state to use
+ * \param state Pointer to a state to use
  *
  * \return Two uniformly distributed \p double values from (0; 1] range as \p double2.
  */
-FQUALIFIERS
-double2 rocrand_uniform_double2(rocrand_state_philox4x32_10 * state)
+__forceinline__ __device__ __host__
+double2 rocrand_uniform_double2(rocrand_state_philox4x32_10* state)
 {
     return rocrand_device::detail::uniform_distribution_double2(rocrand4(state));
 }
@@ -334,12 +330,12 @@ double2 rocrand_uniform_double2(rocrand_state_philox4x32_10 * state)
  * (excluding \p 0.0, including \p 1.0) using Philox generator in \p state, and
  * increments position of the generator by eight.
  *
- * \param state - Pointer to a state to use
+ * \param state Pointer to a state to use
  *
  * \return Four uniformly distributed \p double values from (0; 1] range as \p double4.
  */
-FQUALIFIERS
-double4 rocrand_uniform_double4(rocrand_state_philox4x32_10 * state)
+__forceinline__ __device__ __host__
+double4 rocrand_uniform_double4(rocrand_state_philox4x32_10* state)
 {
     return rocrand_device::detail::uniform_distribution_double4(rocrand4(state), rocrand4(state));
 }
@@ -352,11 +348,12 @@ double4 rocrand_uniform_double4(rocrand_state_philox4x32_10 * state)
  * (excluding \p 0.0f, including \p 1.0f) using MRG31K3P generator in \p state, and
  * increments position of the generator by one.
  *
- * \param state - Pointer to a state to use
+ * \param state Pointer to a state to use
  *
  * \return Uniformly distributed \p float value from (0; 1] range.
  */
-FQUALIFIERS float rocrand_uniform(rocrand_state_mrg31k3p* state)
+__forceinline__ __device__ __host__
+float rocrand_uniform(rocrand_state_mrg31k3p* state)
 {
     return rocrand_device::detail::mrg_uniform_distribution<rocrand_state_mrg31k3p>(state->next());
 }
@@ -369,20 +366,21 @@ FQUALIFIERS float rocrand_uniform(rocrand_state_mrg31k3p* state)
  * (excluding \p 0.0, including \p 1.0) using MRG31K3P generator in \p state, and
  * increments position of the generator by one.
  *
- * \param state - Pointer to a state to use
+ * \param state Pointer to a state to use
  *
  * Note: In this implementation returned \p double value is generated
  * from only 32 random bits (one <tt>unsigned int</tt> value).
  *
  * \return Uniformly distributed \p double value from (0; 1] range.
  */
-FQUALIFIERS double rocrand_uniform_double(rocrand_state_mrg31k3p* state)
+__forceinline__ __device__ __host__
+double rocrand_uniform_double(rocrand_state_mrg31k3p* state)
 {
     return rocrand_device::detail::mrg_uniform_distribution_double<rocrand_state_mrg31k3p>(
         state->next());
 }
 
- /**
+/**
  * \brief Returns a uniformly distributed random <tt>float</tt> value
  * from (0; 1] range.
  *
@@ -390,17 +388,17 @@ FQUALIFIERS double rocrand_uniform_double(rocrand_state_mrg31k3p* state)
  * (excluding \p 0.0f, including \p 1.0f) using MRG32K3A generator in \p state, and
  * increments position of the generator by one.
  *
- * \param state - Pointer to a state to use
+ * \param state Pointer to a state to use
  *
  * \return Uniformly distributed \p float value from (0; 1] range.
  */
-FQUALIFIERS
-float rocrand_uniform(rocrand_state_mrg32k3a * state)
+__forceinline__ __device__ __host__
+float rocrand_uniform(rocrand_state_mrg32k3a* state)
 {
     return rocrand_device::detail::mrg_uniform_distribution<rocrand_state_mrg32k3a>(state->next());
 }
 
- /**
+/**
  * \brief Returns a uniformly distributed random <tt>double</tt> value
  * from (0; 1] range.
  *
@@ -408,21 +406,21 @@ float rocrand_uniform(rocrand_state_mrg32k3a * state)
  * (excluding \p 0.0, including \p 1.0) using MRG32K3A generator in \p state, and
  * increments position of the generator by one.
  *
- * \param state - Pointer to a state to use
+ * \param state Pointer to a state to use
  *
  * Note: In this implementation returned \p double value is generated
  * from only 32 random bits (one <tt>unsigned int</tt> value).
  *
  * \return Uniformly distributed \p double value from (0; 1] range.
  */
-FQUALIFIERS
-double rocrand_uniform_double(rocrand_state_mrg32k3a * state)
+__forceinline__ __device__ __host__
+double rocrand_uniform_double(rocrand_state_mrg32k3a* state)
 {
     return rocrand_device::detail::mrg_uniform_distribution_double<rocrand_state_mrg32k3a>(
         state->next());
 }
 
- /**
+/**
  * \brief Returns a uniformly distributed random <tt>float</tt> value
  * from (0; 1] range.
  *
@@ -430,17 +428,17 @@ double rocrand_uniform_double(rocrand_state_mrg32k3a * state)
  * (excluding \p 0.0f, including \p 1.0f) using XORWOW generator in \p state, and
  * increments position of the generator by one.
  *
- * \param state - Pointer to a state to use
+ * \param state Pointer to a state to use
  *
  * \return Uniformly distributed \p float value from (0; 1] range.
  */
-FQUALIFIERS
-float rocrand_uniform(rocrand_state_xorwow * state)
+__forceinline__ __device__ __host__
+float rocrand_uniform(rocrand_state_xorwow* state)
 {
     return rocrand_device::detail::uniform_distribution(rocrand(state));
 }
 
- /**
+/**
  * \brief Returns a uniformly distributed random <tt>double</tt> value
  * from (0; 1] range.
  *
@@ -448,12 +446,12 @@ float rocrand_uniform(rocrand_state_xorwow * state)
  * (excluding \p 0.0, including \p 1.0) using MRG32K3A generator in \p state, and
  * increments position of the generator by two.
  *
- * \param state - Pointer to a state to use
+ * \param state Pointer to a state to use
  *
  * \return Uniformly distributed \p double value from (0; 1] range.
  */
-FQUALIFIERS
-double rocrand_uniform_double(rocrand_state_xorwow * state)
+__forceinline__ __device__ __host__
+double rocrand_uniform_double(rocrand_state_xorwow* state)
 {
     auto state1 = rocrand(state);
     auto state2 = rocrand(state);
@@ -461,7 +459,7 @@ double rocrand_uniform_double(rocrand_state_xorwow * state)
     return rocrand_device::detail::uniform_distribution_double(state1, state2);
 }
 
- /**
+/**
  * \brief Returns a uniformly distributed random <tt>float</tt> value
  * from (0; 1] range.
  *
@@ -469,12 +467,12 @@ double rocrand_uniform_double(rocrand_state_xorwow * state)
  * (excluding \p 0.0f, including \p 1.0f) using MTGP32 generator in \p state, and
  * increments position of the generator by one.
  *
- * \param state - Pointer to a state to use
+ * \param state Pointer to a state to use
  *
  * \return Uniformly distributed \p float value from (0; 1] range.
  */
-FQUALIFIERS
-float rocrand_uniform(rocrand_state_mtgp32 * state)
+__forceinline__ __device__
+float rocrand_uniform(rocrand_state_mtgp32* state)
 {
     return rocrand_device::detail::uniform_distribution(rocrand(state));
 }
@@ -487,20 +485,20 @@ float rocrand_uniform(rocrand_state_mtgp32 * state)
  * (excluding \p 0.0, including \p 1.0) using MTGP32 generator in \p state, and
  * increments position of the generator by one.
  *
- * \param state - Pointer to a state to use
+ * \param state Pointer to a state to use
  *
  * Note: In this implementation returned \p double value is generated
  * from only 32 random bits (one <tt>unsigned int</tt> value).
  *
  * \return Uniformly distributed \p double value from (0; 1] range.
  */
-FQUALIFIERS
-double rocrand_uniform_double(rocrand_state_mtgp32 * state)
+__forceinline__ __device__
+double rocrand_uniform_double(rocrand_state_mtgp32* state)
 {
     return rocrand_device::detail::uniform_distribution_double(rocrand(state));
 }
 
- /**
+/**
  * \brief Returns a uniformly distributed random <tt>float</tt> value
  * from (0; 1] range.
  *
@@ -508,12 +506,12 @@ double rocrand_uniform_double(rocrand_state_mtgp32 * state)
  * (excluding \p 0.0f, including \p 1.0f) using SOBOL32 generator in \p state, and
  * increments position of the generator by one.
  *
- * \param state - Pointer to a state to use
+ * \param state Pointer to a state to use
  *
  * \return Uniformly distributed \p float value from (0; 1] range.
  */
-FQUALIFIERS
-float rocrand_uniform(rocrand_state_sobol32 * state)
+__forceinline__ __device__ __host__
+float rocrand_uniform(rocrand_state_sobol32* state)
 {
     return rocrand_device::detail::uniform_distribution(rocrand(state));
 }
@@ -526,15 +524,15 @@ float rocrand_uniform(rocrand_state_sobol32 * state)
  * (excluding \p 0.0, including \p 1.0) using SOBOL32 generator in \p state, and
  * increments position of the generator by one.
  *
- * \param state - Pointer to a state to use
+ * \param state Pointer to a state to use
  *
  * Note: In this implementation returned \p double value is generated
  * from only 32 random bits (one <tt>unsigned int</tt> value).
  *
  * \return Uniformly distributed \p double value from (0; 1] range.
  */
-FQUALIFIERS
-double rocrand_uniform_double(rocrand_state_sobol32 * state)
+__forceinline__ __device__ __host__
+double rocrand_uniform_double(rocrand_state_sobol32* state)
 {
     return rocrand_device::detail::uniform_distribution_double(rocrand(state));
 }
@@ -547,11 +545,11 @@ double rocrand_uniform_double(rocrand_state_sobol32 * state)
  * (excluding \p 0.0f, including \p 1.0f) using SCRAMBLED_SOBOL32 generator in \p state, and
  * increments position of the generator by one.
  *
- * \param state - Pointer to a state to use
+ * \param state Pointer to a state to use
  *
  * \return Uniformly distributed \p float value from (0; 1] range.
  */
-FQUALIFIERS
+__forceinline__ __device__ __host__
 float rocrand_uniform(rocrand_state_scrambled_sobol32* state)
 {
     return rocrand_device::detail::uniform_distribution(rocrand(state));
@@ -565,14 +563,14 @@ float rocrand_uniform(rocrand_state_scrambled_sobol32* state)
  * (excluding \p 0.0, including \p 1.0) using SCRAMBLED_SOBOL32 generator in \p state, and
  * increments position of the generator by one.
  *
- * \param state - Pointer to a state to use
+ * \param state Pointer to a state to use
  *
  * Note: In this implementation returned \p double value is generated
  * from only 32 random bits (one <tt>unsigned int</tt> value).
  *
  * \return Uniformly distributed \p double value from (0; 1] range.
  */
-FQUALIFIERS
+__forceinline__ __device__ __host__
 double rocrand_uniform_double(rocrand_state_scrambled_sobol32* state)
 {
     return rocrand_device::detail::uniform_distribution_double(rocrand(state));
@@ -586,11 +584,11 @@ double rocrand_uniform_double(rocrand_state_scrambled_sobol32* state)
  * (excluding \p 0.0, including \p 1.0) using SOBOL64 generator in \p state, and
  * increments position of the generator by one.
  *
- * \param state - Pointer to a state to use
+ * \param state Pointer to a state to use
  *
  * \return Uniformly distributed \p float value from (0; 1] range.
  */
-FQUALIFIERS
+__forceinline__ __device__ __host__
 float rocrand_uniform(rocrand_state_sobol64* state)
 {
     return rocrand_device::detail::uniform_distribution(rocrand(state));
@@ -604,12 +602,12 @@ float rocrand_uniform(rocrand_state_sobol64* state)
  * (excluding \p 0.0, including \p 1.0) using SOBOL64 generator in \p state, and
  * increments position of the generator by one.
  *
- * \param state - Pointer to a state to use
+ * \param state Pointer to a state to use
  *
  * \return Uniformly distributed \p double value from (0; 1] range.
  */
-FQUALIFIERS
-double rocrand_uniform_double(rocrand_state_sobol64 * state)
+__forceinline__ __device__ __host__
+double rocrand_uniform_double(rocrand_state_sobol64* state)
 {
     return rocrand_device::detail::uniform_distribution_double(rocrand(state));
 }
@@ -622,11 +620,11 @@ double rocrand_uniform_double(rocrand_state_sobol64 * state)
  * (excluding \p 0.0, including \p 1.0) using SCRAMBLED_SOBOL64 generator in \p state, and
  * increments position of the generator by one.
  *
- * \param state - Pointer to a state to use
+ * \param state Pointer to a state to use
  *
  * \return Uniformly distributed \p float value from (0; 1] range.
  */
-FQUALIFIERS
+__forceinline__ __device__ __host__
 float rocrand_uniform(rocrand_state_scrambled_sobol64* state)
 {
     return rocrand_device::detail::uniform_distribution(rocrand(state));
@@ -640,11 +638,11 @@ float rocrand_uniform(rocrand_state_scrambled_sobol64* state)
  * (excluding \p 0.0, including \p 1.0) using SCRAMBLED_SOBOL64 generator in \p state, and
  * increments position of the generator by one.
  *
- * \param state - Pointer to a state to use
+ * \param state Pointer to a state to use
  *
  * \return Uniformly distributed \p double value from (0; 1] range.
  */
-FQUALIFIERS
+__forceinline__ __device__ __host__
 double rocrand_uniform_double(rocrand_state_scrambled_sobol64* state)
 {
     return rocrand_device::detail::uniform_distribution_double(rocrand(state));
@@ -658,11 +656,11 @@ double rocrand_uniform_double(rocrand_state_scrambled_sobol64* state)
  * (excluding \p 0.0f, including \p 1.0f) using LFSR113 generator in \p state, and
  * increments position of the generator by one.
  *
- * \param state - Pointer to a state to use
+ * \param state Pointer to a state to use
  *
  * \return Uniformly distributed \p float value from (0; 1] range.
  */
-FQUALIFIERS
+__forceinline__ __device__ __host__
 float rocrand_uniform(rocrand_state_lfsr113* state)
 {
     return rocrand_device::detail::uniform_distribution(rocrand(state));
@@ -676,14 +674,14 @@ float rocrand_uniform(rocrand_state_lfsr113* state)
  * (excluding \p 0.0, including \p 1.0) using LFSR113 generator in \p state, and
  * increments position of the generator by one.
  *
- * \param state - Pointer to a state to use
+ * \param state Pointer to a state to use
  *
  * Note: In this implementation returned \p double value is generated
  * from only 32 random bits (one <tt>unsigned int</tt> value).
  *
  * \return Uniformly distributed \p double value from (0; 1] range.
  */
-FQUALIFIERS
+__forceinline__ __device__ __host__
 double rocrand_uniform_double(rocrand_state_lfsr113* state)
 {
     return rocrand_device::detail::uniform_distribution_double(rocrand(state));
@@ -697,11 +695,12 @@ double rocrand_uniform_double(rocrand_state_lfsr113* state)
  * (excluding \p 0.0, including \p 1.0) using ThreeFry generator in \p state, and
  * increments position of the generator by one.
  *
- * \param state - Pointer to a state to use
+ * \param state Pointer to a state to use
  *
  * \return Uniformly distributed \p float value from (0; 1] range.
  */
-FQUALIFIERS float rocrand_uniform(rocrand_state_threefry2x32_20* state)
+__forceinline__ __device__ __host__
+float rocrand_uniform(rocrand_state_threefry2x32_20* state)
 {
     return rocrand_device::detail::uniform_distribution(rocrand(state));
 }
@@ -714,14 +713,15 @@ FQUALIFIERS float rocrand_uniform(rocrand_state_threefry2x32_20* state)
  * (excluding \p 0.0, including \p 1.0) using ThreeFry generator in \p state, and
  * increments position of the generator by one.
  *
- * \param state - Pointer to a state to use
+ * \param state Pointer to a state to use
  *
  * Note: In this implementation returned \p double value is generated
  * from only 32 random bits (one <tt>unsigned int</tt> value).
  *
  * \return Uniformly distributed \p double value from (0; 1] range.
  */
-FQUALIFIERS double rocrand_uniform_double(rocrand_state_threefry2x32_20* state)
+__forceinline__ __device__ __host__
+double rocrand_uniform_double(rocrand_state_threefry2x32_20* state)
 {
     return rocrand_device::detail::uniform_distribution_double(rocrand(state));
 }
@@ -734,11 +734,12 @@ FQUALIFIERS double rocrand_uniform_double(rocrand_state_threefry2x32_20* state)
  * (excluding \p 0.0, including \p 1.0) using ThreeFry generator in \p state, and
  * increments position of the generator by one.
  *
- * \param state - Pointer to a state to use
+ * \param state Pointer to a state to use
  *
  * \return Uniformly distributed \p float value from (0; 1] range.
  */
-FQUALIFIERS float rocrand_uniform(rocrand_state_threefry2x64_20* state)
+__forceinline__ __device__ __host__
+float rocrand_uniform(rocrand_state_threefry2x64_20* state)
 {
     return rocrand_device::detail::uniform_distribution(rocrand(state));
 }
@@ -751,14 +752,15 @@ FQUALIFIERS float rocrand_uniform(rocrand_state_threefry2x64_20* state)
  * (excluding \p 0.0, including \p 1.0) using ThreeFry generator in \p state, and
  * increments position of the generator by one.
  *
- * \param state - Pointer to a state to use
+ * \param state Pointer to a state to use
  *
  * Note: In this implementation returned \p double value is generated
  * from only 32 random bits (one <tt>unsigned int</tt> value).
  *
  * \return Uniformly distributed \p double value from (0; 1] range.
  */
-FQUALIFIERS double rocrand_uniform_double(rocrand_state_threefry2x64_20* state)
+__forceinline__ __device__ __host__
+double rocrand_uniform_double(rocrand_state_threefry2x64_20* state)
 {
     return rocrand_device::detail::uniform_distribution_double(rocrand(state));
 }
@@ -771,11 +773,12 @@ FQUALIFIERS double rocrand_uniform_double(rocrand_state_threefry2x64_20* state)
  * (excluding \p 0.0, including \p 1.0) using ThreeFry generator in \p state, and
  * increments position of the generator by one.
  *
- * \param state - Pointer to a state to use
+ * \param state Pointer to a state to use
  *
  * \return Uniformly distributed \p float value from (0; 1] range.
  */
-FQUALIFIERS float rocrand_uniform(rocrand_state_threefry4x32_20* state)
+__forceinline__ __device__ __host__
+float rocrand_uniform(rocrand_state_threefry4x32_20* state)
 {
     return rocrand_device::detail::uniform_distribution(rocrand(state));
 }
@@ -788,14 +791,15 @@ FQUALIFIERS float rocrand_uniform(rocrand_state_threefry4x32_20* state)
  * (excluding \p 0.0, including \p 1.0) using ThreeFry generator in \p state, and
  * increments position of the generator by one.
  *
- * \param state - Pointer to a state to use
+ * \param state Pointer to a state to use
  *
  * Note: In this implementation returned \p double value is generated
  * from only 32 random bits (one <tt>unsigned int</tt> value).
  *
  * \return Uniformly distributed \p double value from (0; 1] range.
  */
-FQUALIFIERS double rocrand_uniform_double(rocrand_state_threefry4x32_20* state)
+__forceinline__ __device__ __host__
+double rocrand_uniform_double(rocrand_state_threefry4x32_20* state)
 {
     return rocrand_device::detail::uniform_distribution_double(rocrand(state));
 }
@@ -808,11 +812,12 @@ FQUALIFIERS double rocrand_uniform_double(rocrand_state_threefry4x32_20* state)
  * (excluding \p 0.0, including \p 1.0) using ThreeFry generator in \p state, and
  * increments position of the generator by one.
  *
- * \param state - Pointer to a state to use
+ * \param state Pointer to a state to use
  *
  * \return Uniformly distributed \p float value from (0; 1] range.
  */
-FQUALIFIERS float rocrand_uniform(rocrand_state_threefry4x64_20* state)
+__forceinline__ __device__ __host__
+float rocrand_uniform(rocrand_state_threefry4x64_20* state)
 {
     return rocrand_device::detail::uniform_distribution(rocrand(state));
 }
@@ -825,14 +830,15 @@ FQUALIFIERS float rocrand_uniform(rocrand_state_threefry4x64_20* state)
  * (excluding \p 0.0, including \p 1.0) using ThreeFry generator in \p state, and
  * increments position of the generator by one.
  *
- * \param state - Pointer to a state to use
+ * \param state Pointer to a state to use
  *
  * Note: In this implementation returned \p double value is generated
  * from only 32 random bits (one <tt>unsigned int</tt> value).
  *
  * \return Uniformly distributed \p double value from (0; 1] range.
  */
-FQUALIFIERS double rocrand_uniform_double(rocrand_state_threefry4x64_20* state)
+__forceinline__ __device__ __host__
+double rocrand_uniform_double(rocrand_state_threefry4x64_20* state)
 {
     return rocrand_device::detail::uniform_distribution_double(rocrand(state));
 }
