@@ -1,4 +1,4 @@
-// Copyright (c) 2017-2021 Advanced Micro Devices, Inc. All rights reserved.
+// Copyright (c) 2017-2025 Advanced Micro Devices, Inc. All rights reserved.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -26,11 +26,6 @@
 /// ROCRAND_VERSION % 100 is the patch level,
 /// ROCRAND_VERSION / 100 % 1000 is the minor version,
 /// ROCRAND_VERSION / 100000 is the major version.
-#define ROCRAND_VERSION 300300
-
-// Enables inline asm optimisations
-#if !defined(ROCRAND_ENABLE_INLINE_ASM) && !defined(ROCRAND_DISABLE_INLINE_ASM)
-    #define ROCRAND_ENABLE_INLINE_ASM
-#endif
+#define ROCRAND_VERSION 400100
 
 #endif // ROCRAND_VERSION_H_
